@@ -7,6 +7,12 @@ toplevel_cmake = """
 cmake_minimum_required(VERSION 3.16.3)
 project(wks)
 
+# Libs are in lib/ and binaries in bin/
+include(GNUInstallDirs)
+set(CMAKE_RUNTIME_OUTPUT_DIRECTORY ${CMAKE_CURRENT_BINARY_DIR}/${CMAKE_INSTALL_BINDIR})
+set(CMAKE_LIBRARY_OUTPUT_DIRECTORY ${CMAKE_CURRENT_BINARY_DIR}/${CMAKE_INSTALL_LIBDIR})
+set(CMAKE_ARCHIVE_OUTPUT_DIRECTORY ${CMAKE_CURRENT_BINARY_DIR}/${CMAKE_INSTALL_LIBDIR})
+
 add_subdirectory(src)
 """
 
@@ -19,11 +25,8 @@ add_compile_options(
   $<$<CXX_COMPILER_ID:Clang>:-fcolor-diagnostics>
 )
 
-# Libs are in lib/ and binaries in bin/
-include(GNUInstallDirs)
-set(CMAKE_RUNTIME_OUTPUT_DIRECTORY ${CMAKE_CURRENT_BINARY_DIR}/${CMAKE_INSTALL_BINDIR})
-set(CMAKE_LIBRARY_OUTPUT_DIRECTORY ${CMAKE_CURRENT_BINARY_DIR}/${CMAKE_INSTALL_LIBDIR})
-set(CMAKE_ARCHIVE_OUTPUT_DIRECTORY ${CMAKE_CURRENT_BINARY_DIR}/${CMAKE_INSTALL_LIBDIR})
+# Easy build type selection
+set_property(CACHE CMAKE_BUILD_TYPE PROPERTY STRINGS Release Debug RelWithDebInfo)
 
 # Generate compile_commands.json to make it easier to work with clang based tools
 set(CMAKE_EXPORT_COMPILE_COMMANDS ON)
@@ -70,13 +73,12 @@ def generate():
       cmake_directory = os.path.realpath(directory)
       dname = os.path.basename(os.path.dirname(directory))
       name = os.path.basename(directory)
-      project = '%s_%s' % (dname, name)
-
+      project = '%s/%s' % (dname, name)
+        
       if cmake_name:
-        project += '_' + cmake_name
-        cmake_directory += '/' + cmake_name
+        project += '/' + cmake_name
 
-      cmake += "add_subdirectory(%s %s)\n" % (cmake_directory, project)
+      cmake += "add_subdirectory(%s)\n" % (project)
       print('- %s [%s]' % (project, Style.DIM + cmake_directory + Style.RESET_ALL))
 
   f = open(env.sources_directory + '/CMakeLists.txt', 'w')
